@@ -17,8 +17,8 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
  *************************************************************************************/
 
-#ifndef ANALITZATEST_H
-#define ANALITZATEST_H
+#ifndef PLANECURVETEST_H
+#define PLANECURVETEST_H
 
 #include <QObject>
 #include <QSharedPointer>
@@ -32,7 +32,7 @@ class PlaneCurveTest : public QObject
 {
 Q_OBJECT
     public:
-        PlaneCurveTest(QObject *parent = 0);
+        PlaneCurveTest(QObject *parent = nullptr);
         ~PlaneCurveTest();
 
     private Q_SLOTS:
